# Tele-botify
Tele-botify is a Python library for developing Telegram bots

## Installation
Install using pip
```shell
pip install telebotify
```

## Usage
Make an instance of Bot providing the bot API key. Optionally, provide a webhook url, a commands dictionary and a certificate path too.